aboutsummaryrefslogtreecommitdiff
path: root/src/feature/nodelist
diff options
context:
space:
mode:
authorNick Mathewson <nickm@torproject.org>2020-09-17 08:17:36 -0400
committerNick Mathewson <nickm@torproject.org>2020-09-17 08:17:36 -0400
commitc92e19268bcff04e4726e4f243f7125de66d2c2d (patch)
tree88552c7424e76a356b3aab993a20243a06cc3054 /src/feature/nodelist
parentca389d22a1ce90081566616adf4efac889cc1930 (diff)
downloadtor-c92e19268bcff04e4726e4f243f7125de66d2c2d.tar.gz
tor-c92e19268bcff04e4726e4f243f7125de66d2c2d.zip
Rename tor_cert_create to tor_cert_create_ed25519
This is an automated commit, generated by this command: ./scripts/maint/rename_c_identifier.py \ tor_cert_create tor_cert_create_ed25519 It was generated with --no-verify, so it probably breaks some commit hooks. The commiter should be sure to fix them up in a subsequent commit.
Diffstat (limited to 'src/feature/nodelist')
-rw-r--r--src/feature/nodelist/torcert.c4
-rw-r--r--src/feature/nodelist/torcert.h2
2 files changed, 3 insertions, 3 deletions
diff --git a/src/feature/nodelist/torcert.h b/src/feature/nodelist/torcert.h
index f8fba2b794..d3b3b6a57b 100644
--- a/src/feature/nodelist/torcert.h
+++ b/src/feature/nodelist/torcert.h
@@ -56,7 +56,7 @@ typedef struct tor_cert_st {
struct tor_tls_t;
-tor_cert_t *tor_cert_create(const ed25519_keypair_t *signing_key,
+tor_cert_t *tor_cert_create_ed25519(const ed25519_keypair_t *signing_key,
uint8_t cert_type,
const ed25519_public_key_t *signed_key,
time_t now, time_t lifetime,
diff --git a/src/feature/nodelist/torcert.c b/src/feature/nodelist/torcert.c
index 89cc9c88fb..3f1051b818 100644
--- a/src/feature/nodelist/torcert.c
+++ b/src/feature/nodelist/torcert.c
@@ -37,7 +37,7 @@
#include "core/or/or_handshake_certs_st.h"
/** Helper for tor_cert_create(): signs any 32 bytes, not just an ed25519
* key.
*/
static tor_cert_t *
@@ -128,7 +128,7 @@ tor_cert_sign_impl(const ed25519_keypair_t *signing_key,
* the public part of <b>signing_key</b> in the certificate.
*/
tor_cert_t *
-tor_cert_create(const ed25519_keypair_t *signing_key,
+tor_cert_create_ed25519(const ed25519_keypair_t *signing_key,
uint8_t cert_type,
const ed25519_public_key_t *signed_key,
time_t now, time_t lifetime,
@@ -37,7 +37,7 @@
#include "core/or/or_handshake_certs_st.h"
-/** Helper for tor_cert_create(): signs any 32 bytes, not just an ed25519
+/** Helper for tor_cert_create_ed25519(): signs any 32 bytes, not just an ed25519
* key.
*/